from django.shortcuts import render

from .models import Category, Question

def index(request):
    """
    This displays the FAQ page.
    """

    categories = Category.objects.all()
    questions = Question.objects.filter(active=True)

    return render(request, 'faq/index.html', {'categories': categories, 'questions': questions})



# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):

        # Changing field 'Question.question'
        db.alter_column(u'faq_question', 'question', self.gf('django.db.models.fields.CharField')(max_length=255))

    def backwards(self, orm):

        # Changing field 'Question.question'
        db.alter_column(u'faq_question', 'question', self.gf('django.db.models.fields.TextField')())

    models = {
        u'faq.category': {
            'Meta': {'ordering': "['order', 'title']", 'object_name': 'Category'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'order': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        u'faq.question': {
            'Meta': {'ordering': "['order', 'question']", 'object_name': 'Question'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'answer': ('django.db.models.fields.TextField', [], {}),
            'category': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['faq.Category']"}),
            'created_at': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'order': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'question': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'updated_at': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'})
        }
    }

    complete_apps = ['faq']


from django.contrib import admin

from .models import Category, Question
from .forms import QuestionAdminForm


class CategoryAdmin(admin.ModelAdmin):
    list_display = ['order', 'title']
    list_display_links = ['title']


class QuestionAdmin(admin.ModelAdmin):
    form = QuestionAdminForm
    list_display = ['order', 'question', 'active']
    list_display_links = ['question']


admin.site.register(Category, CategoryAdmin)
admin.site.register(Question, QuestionAdmin)



from django.db import models


class Category(models.Model):
    title = models.CharField(max_length=100)
    order = models.IntegerField(default=0)

    name_field = 'title'

    class Meta:
        ordering = ['order', 'title']
        verbose_name_plural = 'categories'

    def __unicode__(self):
        return self.title

    @property
    def questions(self):
        if not hasattr(self, '_questions'):
            self._questions = self.question_set.filter(active=True)
        return self._questions


class Question(models.Model):
    category = models.ForeignKey(Category)
    question = models.CharField(max_length=255)
    answer = models.TextField()

    order = models.IntegerField(default=0)
    active = models.BooleanField(default=True)

    created_at = models.DateTimeField(auto_now_add=True)
    updated_at = models.DateTimeField(auto_now=True)

    objects = models.Manager()

    class Meta:
        ordering = ['order', 'question']

    def __unicode__(self):
        return self.question



from django.utils.translation import ugettext_lazy as _
from cms.app_base import CMSApp
from cms.apphook_pool import apphook_pool


class FaqHook(CMSApp):
    name = _('FAQs')
    urls = ["faq.urls"]

apphook_pool.register(FaqHook)


from django.forms import ModelForm
from suit_redactor.widgets import RedactorWidget

class QuestionAdminForm(ModelForm):
    class Meta:
        widgets = {
            'answer': RedactorWidget(editor_options={
                'lang': 'en',
                'minHeight': '200',
                'buttons': [
                    'html', '|',
                    'bold', 'italic', 'deleted', 'underline', '|',
                    'unorderedlist', 'orderedlist', '|',
                    'alignleft', 'aligncenter', 'alignright', 'justify', '|',
                    'link'
                ]
            }),
        }



import os
from setuptools import setup, find_packages

# Utility function to read the README file.
# Used for the long_description.  It's nice, because now 1) we have a top level
# README file and 2) it's easier to type in the README file than to put a raw
# string in below ...
def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name = "farm-faq",
    version = "0.9",
    install_requires=[
        'django-suit',
        'django-suit-redactor',
    ],
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    author = "Jon Atkinson",
    author_email = "jon@wearefarm.com",
    description = "Provides FAQ implementation",
    license = "BSD",
    keywords = "faq",
    url = "",
    long_description=read('README.rst'),
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
    ],
)



# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Category'
        db.create_table(u'faq_category', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=100)),
            ('order', self.gf('django.db.models.fields.IntegerField')(default=0)),
        ))
        db.send_create_signal(u'faq', ['Category'])

        # Adding model 'Question'
        db.create_table(u'faq_question', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('category', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['faq.Category'])),
            ('question', self.gf('django.db.models.fields.TextField')()),
            ('answer', self.gf('django.db.models.fields.TextField')()),
            ('order', self.gf('django.db.models.fields.IntegerField')(default=0)),
            ('active', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('created_at', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('updated_at', self.gf('django.db.models.fields.DateTimeField')(auto_now=True, blank=True)),
        ))
        db.send_create_signal(u'faq', ['Question'])


    def backwards(self, orm):
        # Deleting model 'Category'
        db.delete_table(u'faq_category')

        # Deleting model 'Question'
        db.delete_table(u'faq_question')


    models = {
        u'faq.category': {
            'Meta': {'ordering': "['order', 'title']", 'object_name': 'Category'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'order': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        u'faq.question': {
            'Meta': {'ordering': "['order', 'question']", 'object_name': 'Question'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'answer': ('django.db.models.fields.TextField', [], {}),
            'category': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['faq.Category']"}),
            'created_at': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'order': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'question': ('django.db.models.fields.TextField', [], {}),
            'updated_at': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'})
        }
    }

    complete_apps = ['faq']